Grunt class abstract

This is the implementation class that processes a long-running task

Implementers
Available extensions

Constructors

Grunt()

Properties

channel → GruntChannel
no setter
currentStatus → WorkStatus
no setter
hashCode → int
The hash code for this object.
no setterinherited
isShuttingDown → bool

Available on Grunt, provided by the GruntExt extension

no setter
jobId → String
The specific job that this grunt is processing currently
no setter
key → String
A unique key that identifies this worker
no setter
log → Logger
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
workPhase ↔ WorkPhase
getter/setter pair

Methods

initialize(GruntChannel channel) → FutureOr
Initializes and creates a job id
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendStatus() → void

Available on Grunt, provided by the GruntExt extension

start(dynamic params) → FutureOr
Instructs the agent to start processing
stop() → FutureOr
Instructs the agent to stop
toString() → String
A string representation of this object.
inherited
withPhase(WorkPhase phase, FutureOr exec()) → bool

Available on Grunt, provided by the GruntExt extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited