Supervisor<G extends Grunt> class

Constructors

Supervisor({required Type gruntType, required DuplexChannel grunt})
Supervisor.debug(GruntFactory<G> fn)
factory

Properties

grunt → DuplexChannel
This is how we send and receive messages to/from the worker
final
gruntType → Type
final
hashCode → int
The hash code for this object.
no setterinherited
jobId → String?
no setter
onStatus → Stream<WorkStatus>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → WorkStatus
no setter

Methods

close() → Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start({dynamic params, Duration? timeout}) → Future
stop() → Future
toString() → String
A string representation of this object.
inherited
waitFor(WorkPhase t, {Duration? timeout, FutureOr<WorkStatus> onTimeout()?}) → Future

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

log → Logger
final

Static Methods

create<G extends Grunt>(GruntFactory<G> entry, {bool debug = false, required bool isProduction}) → Future<Supervisor<Grunt>>